## Findings

Jazzer has found the following vulnerabilities and bugs.

As Jazzer is used to fuzz JVM projects in OSS-Fuzz, further findings are listed [on the OSS-Fuzz issue tracker](https://bugs.chromium.org/p/oss-fuzz/issues/list).

If you find bugs with Jazzer, we would like to hear from you!
Feel free to [open an issue](https://github.com/CodeIntelligenceTesting/jazzer/issues/new) or submit a pull request.


| Project                                                                                                                                   | Bug                                                                                           | Status                                                                                                                                             | CVE                                                                             | found by                                                                |
|-------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------|-------------------------------------------------------------------------|
| [hsqldb](https://hsqldb.org/)                                                                                                             | Remote code execution via prepared statement values                                           | [recommended workaround](https://hsqldb.org/doc/2.0/guide/sqlroutines-chapt.html#src_jrt_access_control)                                           | [CVE-2022-41853](https://nvd.nist.gov/vuln/detail/CVE-2022-41853)               | [OSS-Fuzz](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=50212) |
| [protocolbuffers/protobuf](https://github.com/protocolbuffers/protobuf)                                                                   | Small protobuf messages can consume minutes of CPU time                                       | [fixed](https://github.com/protocolbuffers/protobuf/security/advisories/GHSA-h4h5-3hr4-j3g2)                                                       | [CVE-2022-3171](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-3171)   | [OSS-Fuzz](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=39330) |
| [OpenJDK](https://github.com/openjdk/jdk)                                                                                                 | `OutOfMemoryError` via a small BMP image                                                      | [fixed](https://openjdk.java.net/groups/vulnerability/advisories/2022-01-18)                                                                       | [CVE-2022-21360](https://nvd.nist.gov/vuln/detail/CVE-2022-21360)               | [Code Intelligence](https://code-intelligence.com)                      |
| [OpenJDK](https://github.com/openjdk/jdk)                                                                                                 | `OutOfMemoryError` via a small TIFF image                                                     | [fixed](https://openjdk.java.net/groups/vulnerability/advisories/2022-01-18)                                                                       | [CVE-2022-21366](https://nvd.nist.gov/vuln/detail/CVE-2022-21366)               | [Code Intelligence](https://code-intelligence.com)                      |
| [protocolbuffers/protobuf](https://github.com/protocolbuffers/protobuf)                                                                   | Small protobuf messages can consume minutes of CPU time                                       | [fixed](https://github.com/protocolbuffers/protobuf/security/advisories/GHSA-wrvw-hg22-4m67)                                                       | [CVE-2021-22569](https://nvd.nist.gov/vuln/detail/CVE-2021-22569)               | [OSS-Fuzz](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=39330) |
| [jhy/jsoup](https://github.com/jhy/jsoup)                                                                                                 | More than 19 Bugs found in HTML and XML parser                                                | [fixed](https://github.com/jhy/jsoup/security/advisories/GHSA-m72m-mhq2-9p6c)                                                                      | [CVE-2021-37714](https://nvd.nist.gov/vuln/detail/CVE-2021-37714)               | [Code Intelligence](https://code-intelligence.com)                      |
| [Apache/commons-compress](https://commons.apache.org/proper/commons-compress/)                                                            | Infinite loop when loading a crafted 7z                                                       | fixed                                                                                                                                              | [CVE-2021-35515](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35515) | [Code Intelligence](https://code-intelligence.com)                      |
| [Apache/commons-compress](https://commons.apache.org/proper/commons-compress/)                                                            | `OutOfMemoryError` when loading a crafted 7z                                                  | fixed                                                                                                                                              | [CVE-2021-35516](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35516) | [Code Intelligence](https://code-intelligence.com)                      |
| [Apache/commons-compress](https://commons.apache.org/proper/commons-compress/)                                                            | Infinite loop when loading a crafted TAR                                                      | fixed                                                                                                                                              | [CVE-2021-35517](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35517) | [Code Intelligence](https://code-intelligence.com)                      |
| [Apache/commons-compress](https://commons.apache.org/proper/commons-compress/)                                                            | `OutOfMemoryError` when loading a crafted ZIP                                                 | fixed                                                                                                                                              | [CVE-2021-36090](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36090) | [Code Intelligence](https://code-intelligence.com)                      |
| [Apache/PDFBox](https://pdfbox.apache.org/)                                                                                               | Infinite loop when loading a crafted PDF                                                      | fixed                                                                                                                                              | [CVE-2021-27807](https://cve.mitre.org/cgi-bin/cvename.cgi?name=2021-27807)     | [Code Intelligence](https://code-intelligence.com)                      |
| [Apache/PDFBox](https://pdfbox.apache.org/)                                                                                               | OutOfMemoryError when loading a crafted PDF                                                   | fixed                                                                                                                                              | [CVE-2021-27906](https://cve.mitre.org/cgi-bin/cvename.cgi?name=2021-27906)     | [Code Intelligence](https://code-intelligence.com)                      |
| [netplex/json-smart-v1](https://github.com/netplex/json-smart-v1) <br/> [netplex/json-smart-v2](https://github.com/netplex/json-smart-v2) | `JSONParser#parse` throws an undeclared exception                                             | [fixed](https://github.com/netplex/json-smart-v2/issues/60)                                                                                        | [CVE-2021-27568](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-27568) | [@GanbaruTobi](https://github.com/GanbaruTobi)                          |
| [OWASP/json-sanitizer](https://github.com/OWASP/json-sanitizer)                                                                           | Output can contain`</script>` and `]]>`, which allows XSS                                     | [fixed](https://groups.google.com/g/json-sanitizer-support/c/dAW1AeNMoA0)                                                                          | [CVE-2021-23899](https://cve.mitre.org/cgi-bin/cvename.cgi?name=2021-23899)     | [Code Intelligence](https://code-intelligence.com)                      |
| [OWASP/json-sanitizer](https://github.com/OWASP/json-sanitizer)                                                                           | Output can be invalid JSON and undeclared exceptions can be thrown                            | [fixed](https://groups.google.com/g/json-sanitizer-support/c/dAW1AeNMoA0)                                                                          | [CVE-2021-23900](https://cve.mitre.org/cgi-bin/cvename.cgi?name=2021-23900)     | [Code Intelligence](https://code-intelligence.com)                      |
| [alibaba/fastjon](https://github.com/alibaba/fastjson)                                                                                    | `JSON#parse` throws undeclared exceptions                                                     | [fixed](https://github.com/alibaba/fastjson/issues/3631)                                                                                           |                                                                                 | [Code Intelligence](https://code-intelligence.com)                      |
| [Apache/commons-compress](https://commons.apache.org/proper/commons-compress/)                                                            | Infinite loop and `OutOfMemoryError` in `TarFile`                                             | [fixed](https://issues.apache.org/jira/browse/COMPRESS-569)                                                                                        |                                                                                 | [Code Intelligence](https://code-intelligence.com)                      |
| [Apache/commons-compress](https://commons.apache.org/proper/commons-compress/)                                                            | `NullPointerException` in `ZipFile`                                                           | [fixed](https://issues.apache.org/jira/browse/COMPRESS-568)                                                                                        |                                                                                 | [Code Intelligence](https://code-intelligence.com)                      |
| [Apache/commons-imaging](https://commons.apache.org/proper/commons-imaging/)                                                              | Parsers for multiple image formats throw undeclared exceptions                                | [reported](https://issues.apache.org/jira/browse/IMAGING-279?jql=project%20%3D%20%22Commons%20Imaging%22%20AND%20reporter%20%3D%20Meumertzheim%20) |                                                                                 | [Code Intelligence](https://code-intelligence.com)                      |
| [Apache/PDFBox](https://pdfbox.apache.org/)                                                                                               | Various undeclared exceptions                                                                 | [fixed](https://issues.apache.org/jira/browse/PDFBOX-5108?jql=project%20%3D%20PDFBOX%20AND%20reporter%20in%20(Meumertzheim))                       |                                                                                 | [Code Intelligence](https://code-intelligence.com)                      |
| [cbeust/klaxon](https://github.com/cbeust/klaxon)                                                                                         | Default parser throws runtime exceptions                                                      | [fixed](https://github.com/cbeust/klaxon/pull/330)                                                                                                 |                                                                                 | [Code Intelligence](https://code-intelligence.com)                      |
| [FasterXML/jackson-dataformats-binary](https://github.com/FasterXML/jackson-dataformats-binary)                                           | `CBORParser` throws an undeclared exception due to missing bounds checks when parsing Unicode | [fixed](https://github.com/FasterXML/jackson-dataformats-binary/issues/236)                                                                        |                                                                                 | [Code Intelligence](https://code-intelligence.com)                      |
| [FasterXML/jackson-dataformats-binary](https://github.com/FasterXML/jackson-dataformats-binary)                                           | `CBORParser` throws an undeclared exception on dangling arrays                                | [fixed](https://github.com/FasterXML/jackson-dataformats-binary/issues/240)                                                                        |                                                                                 | [Code Intelligence](https://code-intelligence.com)                      |
| [ngageoint/tiff-java](https://github.com/ngageoint/tiff-java)                                                                             | `readTiff ` Index Out Of Bounds                                                               | [fixed](https://github.com/ngageoint/tiff-java/issues/38)                                                                                          |                                                                                 | [@raminfp](https://github.com/raminfp)                                  |
| [google/re2j](https://github.com/google/re2j)                                                                                             | `NullPointerException` in `Pattern.compile`                                                   | [reported](https://github.com/google/re2j/issues/148)                                                                                              |                                                                                 | [@schirrmacher](https://github.com/schirrmacher)                        |
| [google/gson](https://github.com/google/gson)                                                                                             | `ArrayIndexOutOfBounds` in `ParseString`                                                      | [fixed](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=40838)                                                                               |                                                                                 | [@DavidKorczynski](https://twitter.com/Davkorcz)                        |

